@@ -5,7 +5,7 @@ package SHARYANTO::Role::BorderStyle;
 use 5.010;
 use Moo::Role;
 
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.67'; # VERSION
 
 with 'SHARYANTO::Role::TermAttrs';
 
@@ -122,7 +122,7 @@ SHARYANTO::Role::BorderStyle - Role for class wanting to support border styles
 
 =head1 VERSION
 
-version 0.66
+version 0.67
 
 =head1 DESCRIPTION
 
@@ -159,11 +159,6 @@ A character can also be a coderef that will be called with C<< ($self, %args)
 >>. Arguments in C<%args> contains information such as C<name>, C<y>, C<x>, C<n>
 (how many times should character be repeated), etc.
 
-=head1 FUNCTIONS
-
-
-None are exported by default, but they are exportable.
-
 =head1 ATTRIBUTES
 
 =head2 border_style => HASH
@@ -192,8 +187,7 @@ Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Roles>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Roles>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=SHARYANTO-Roles>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
